@@ -1,6 +1,7 @@
 from maggma.api.query_operator import PaginationQuery, SparseFieldsQuery
 from maggma.api.resource import ReadOnlyResource
 from emmet.api.core.global_header import GlobalHeaderProcessor
+from emmet.api.core.settings import MAPISettings
 
 from emmet.core.similarity import SimilarityDoc
 
@@ -17,6 +18,7 @@ def similarity_resource(similarity_store):
         tags=["Similarity"],
         enable_default_search=False,
         disable_validation=True,
+        timeout=MAPISettings().TIMEOUT
     )
 
     return resource
